From 478520dc710998ff9c5a8e2933a318281ad46814 Mon Sep 17 00:00:00 2001
From: Carmelo Pellegrino <carmelo.pellegrino@gmail.com>
Date: Mon, 25 May 2015 15:35:50 +0200
Subject: [PATCH] reading the destination of the detectorfile from shell var

---
 patch-control.sh | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/patch-control.sh b/patch-control.sh
index fa02b9d..0969f2e 100755
--- a/patch-control.sh
+++ b/patch-control.sh
@@ -11,7 +11,8 @@
 # The configuration of this very script is perfomed via shell variables.
 # Here the list of parameters is reported
 #
 # DM_EXE_DIR  -> the absolute path to the DetectorControl.exe program
 # PC_CONF_DIR -> the absolute path of the pc.cfg configuration file
 
 function put_lock() {
@@ -158,7 +159,7 @@ JGetMessage -H localhost -T MSG -d 3 >${daq_log_file} &
 PROCS=(${PROCS[*]} $!)
 
 # Copy selected run setup file, changing the run number
-cat ${rs_file} | sed -e "s/RUNNUMBER/${run_number}/" >dm.detectorfile
+cat ${rs_file} | sed -e "s/RUNNUMBER/${run_number}/" >${DM_DATA_DIR}/dm.detectorfile
 
 run_start_time=`nowUTC`
 
@@ -11,7 +11,8 @@
 # Here the list of parameters is reported
 #
-# DM_EXE_DIR  -> the absolute path to the DetectorControl.exe program
+# DM_EXE_DIR  -> the absolute path of the folder which contain DetectorControl.exe
+# DM_DATA_DIR -> the absolute path of the folder which contain the detectorfile
 # PC_CONF_DIR -> the absolute path of the pc.cfg configuration file
 
-- 
GitLab